View source: R/eval_scenario_cont_2arm.R
| eval_scenario_cont_2arm | R Documentation |
The eval_scenario_cont_2arm function is designed to evaluate
repeated-sampling operating characteristics for a two-arm comparative trial
with a continuous endpoint under one borrowing strategy: self-adapting
mixture prior (SAM), robust MAP prior with fixed weight (rMAP), or
non-informative prior (NP).
eval_scenario_cont_2arm(
if.prior,
nf.prior,
prior.t = nf.prior,
n.t,
n,
sigma.t,
sigma,
theta.t,
theta,
cutoff,
delta,
method = c("SAM", "rMAP", "NP"),
alternative = c("greater", "less"),
margin = 0,
weight_rMAP = 0.5,
method.w = "LRT",
prior.odds = 1,
rel.tol = 1e-06,
n_sd_int = 8
)
if.prior |
Informative prior constructed based on historical data for the control arm, represented (approximately) as a normal mixture prior. |
nf.prior |
Non-informative prior used as the robustifying component for the control arm prior. |
prior.t |
Prior used for the treatment arm. If missing, the default
value is set to be |
n.t |
Number of subjects in the treatment arm. |
n |
Number of subjects in the control arm. |
sigma.t |
Known sampling standard deviation in the treatment arm. |
sigma |
Known sampling standard deviation in the control arm. |
theta.t |
True treatment arm mean. |
theta |
True control arm mean. |
cutoff |
Posterior probability cutoff used for decision making.
Rejection occurs if the posterior probability exceeds |
delta |
Clinically significant difference used for the SAM prior.
This argument is only used when |
method |
Borrowing strategy for the control arm. Must be one of
|
alternative |
Direction of the posterior decision. Must be one of
|
margin |
Clinical margin. Must be a non-negative scalar. The default
value is |
weight_rMAP |
Weight assigned to the informative prior component
( |
method.w |
Methods used to determine the mixture weight for SAM priors.
The default method is "LRT" (Likelihood Ratio Test), the alternative option
is "PPR" (Posterior Probability Ratio). See |
prior.odds |
The prior probability of |
rel.tol |
Relative tolerance passed to numerical integration. |
n_sd_int |
Half-width of the numerical integration region for each arm, expressed as a multiple of the corresponding standard error. |
The treatment effect is defined as \tau = \theta_t - \theta,
where \theta_t and \theta denote the true means in the
treatment and control arms, respectively.
For a given true scenario (\theta_t, \theta), this function computes
the repeated-sampling rejection probability, bias, root mean squared error
(RMSE), and mean borrowing weight using one-dimensional numerical
integration.
The rejection probability is computed by reducing the repeated-sampling decision rule to a one-dimensional integral over the control-arm sample mean.
Bias and RMSE are evaluated for the posterior mean estimator of the control
arm mean \theta. Both are computed from one-dimensional first and
second moments of the control-arm posterior mean. The mean borrowing weight
is computed by one-dimensional integration over the control-arm sample mean.
Under null scenarios, reject_prob corresponds to type I error. Under
alternative scenarios, it corresponds to power.
A one-row data frame with the following columns:
True control arm mean.
True treatment arm mean.
True treatment effect, \tau = \theta_t - \theta.
Borrowing method used.
Direction of the posterior decision.
Posterior probability cutoff used for decision making.
Clinical margin used for inference.
Repeated-sampling rejection probability.
Bias of the posterior mean estimator of \theta.
Root mean squared error of the posterior mean estimator of \theta.
Average borrowing weight under the specified method.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.